eventChannel property
The event channel used to receive events from the native platform.
Implementation
@visibleForTesting
final eventChannel = const EventChannel('sprig_flutter_plugin/events');
The event channel used to receive events from the native platform.
@visibleForTesting
final eventChannel = const EventChannel('sprig_flutter_plugin/events');