MethodChannelSprigFlutterPlugin class
An implementation of SprigFlutterPluginPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- SprigFlutterPluginPlatform
- MethodChannelSprigFlutterPlugin
Constructors
Properties
- eventChannel → EventChannel
-
The event channel used to receive events from the native platform.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
configure(
{required String environment, Map< String, String> ? configuration}) → Future<void> -
override
-
dismissActiveSurvey(
) → Future< void> -
override
-
getPlatformVersion(
) → Future< String?> -
override
-
logout(
) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pauseDisplayingSurveys(
) → Future< void> -
override
-
present(
) → Future< void> -
override
-
presentSurvey(
{required int surveyId}) → Future< void> -
override
-
registerEventListener(
{required SprigLifecycleEvent eventType, required dynamic onCompletion(Map< Object?, Object?> )}) → Future<void> -
override
-
removeVisitorAttributes(
{required List< String> attributes}) → Future<void> -
override
-
sdkVersion(
) → Future< String?> -
override
-
setEmailAddress(
{required String emailAddress}) → Future< void> -
override
-
setPreviewKey(
{required String previewKey}) → Future< void> -
override
-
setUserIdentifier(
{required String identifier}) → Future< void> -
override
-
setVisitorAttribute(
{required String key, required String value}) → Future< void> -
override
-
setVisitorAttributesAndIdentify(
{required Map< String, String> attributes, required String userId, String? partnerAnonymousId}) → Future<void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
track(
{required String eventName, required dynamic onCompletion(SprigSurveyState)}) → Future< void> -
override
-
trackAndIdentify(
{required String eventName, required String userId, required String partnerAnonymousId, required dynamic onCompletion(SprigSurveyState)}) → Future< void> -
override
-
trackAndPresent(
{required String eventName}) → Future< void> -
override
-
trackIdentifyAndPresent(
{required String eventName, String? userId, String? partnerAnonymousId}) → Future< void> -
override
-
trackWithProperties(
{required String eventName, String? userId, String? partnerAnonymousId, required Map< String, dynamic> properties, required dynamic onCompletion(SprigSurveyState)}) → Future<void> -
override
-
unpauseDisplayingSurveys(
) → Future< void> -
override
-
visitorIdentifierString(
) → Future< String?> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited